<?php
/***
	***	@Error handling: Registering
	***/
	add_action('um_ajax_submit_form_errors_hook__registration', 'um_ajax_submit_form_errors_hook__registration', 10);
	function um_ajax_submit_form_errors_hook__registration($args){
		$can_register = get_option('users_can_register');
		$json = array('status' => 'error', 'message' => '', 'redirect' => false);
		if ( !$can_register ) {
            wp_die(wp_json_encode(
                array_replace($json, array(
                    'status' => 'error',
                    'message' => um_return_update_notice('registration_disabled', true),
                    'redirect' => false
                ))
            ));
		}
	}
	/***
	***	@Error handling: blocked emails
	***/
	add_action('um_ajax_submit_form_errors_hook__blockedemails', 'um_ajax_submit_form_errors_hook__blockedemails', 10);
	function um_ajax_submit_form_errors_hook__blockedemails($args){
		$json = array('status' => 'error', 'message' => '', 'redirect' => false);
		$emails = um_get_option('blocked_emails');
		if ( !$emails )
			return;
		$emails = array_map("rtrim", explode("\n", $emails));
		if ( isset( $args['user_email'] ) && is_email( $args['user_email'] ) ) {
			$domain = explode('@', $args['user_email'] );
			$check_domain = str_replace($domain[0], '*', $args['user_email']);
			if ( in_array( $args['user_email'], $emails ) )
                wp_die(wp_json_encode(
                    array_replace($json, array(
                        'status' => 'error',
                        'message' => um_return_update_notice('blocked_email', true),
                        'redirect' => false
                    ))
                ));
			if ( in_array( $check_domain, $emails ) )
                wp_die(wp_json_encode(
                    array_replace($json, array(
                        'status' => 'error',
                        'message' => um_return_update_notice('blocked_domain', true),
                        'redirect' => false
                    ))
                ));
		}
		if ( isset( $args['username'] ) && is_email( $args['username'] ) ) {
			$domain = explode('@', $args['username'] );
			$check_domain = str_replace($domain[0], '*', $args['username']);
			if ( in_array( $args['username'], $emails ) )
                wp_die(wp_json_encode(
                    array_replace($json, array(
                        'status' => 'error',
                        'message' => um_return_update_notice('blocked_email', true),
                        'redirect' => false
                    ))
                ));
			if ( in_array( $check_domain, $emails ) )
                wp_die(wp_json_encode(
                    array_replace($json, array(
                        'status' => 'error',
                        'message' => um_return_update_notice('blocked_domain', true),
                        'redirect' => false
                    ))
                ));
		}
	}
	/***
	***	@Error handling: blocked IPs
	***/
	add_action('um_ajax_submit_form_errors_hook__blockedips', 'um_ajax_submit_form_errors_hook__blockedips', 10);
	function um_ajax_submit_form_errors_hook__blockedips($args){
		$json = array('status' => 'error', 'message' => '', 'redirect' => false);
		$ips = um_get_option('blocked_ips');
		if ( !$ips )
			return;
		$ips = array_map("rtrim", explode("\n", $ips));
		$user_ip = um_user_ip();
		foreach($ips as $ip) {
			$ip = str_replace('*','',$ip);
			if ( !empty( $ip ) && strpos($user_ip, $ip) === 0) {
                wp_die(wp_json_encode(
                    array_replace($json, array(
                        'status' => 'error',
                        'message' => um_return_update_notice('blocked_ip', true),
                        'redirect' => false
                    ))
                ));
			}
		}
	}
	/***
	***	@Error handling: blocked words during sign up
	***/
	add_action('um_ajax_submit_form_errors_hook__blockedwords', 'um_ajax_submit_form_errors_hook__blockedwords', 10);
	function um_ajax_submit_form_errors_hook__blockedwords($args){
		$form_id = $args['form_id'];
		$mode = $args['mode'];
		$fields = unserialize( $args['custom_fields'] );
		$words = um_get_option('blocked_words');
		if ( $words != '' ) {
			$words = array_map("rtrim", explode("\n", $words));
			if( isset( $fields ) && ! empty( $fields ) && is_array( $fields ) ){
				foreach( $fields as $key => $array ) {
					if ( isset($array['validate']) && in_array( $array['validate'], array('unique_username','unique_email','unique_username_or_email') ) ) {
						if ( !UM()->form()->has_error( $key ) && isset( $args[$key] ) && in_array( $args[$key], $words ) ) {
							UM()->form()->add_error( $key,  __('You are not allowed to use this word as your username.','ultimate-member') );
						}
					}
				}
			}
		}
	}
	/***
	***	@Error handling
	***/
	add_action('um_ajax_submit_form_errors_hook', 'um_ajax_submit_form_errors_hook', 10);
	function um_ajax_submit_form_errors_hook( $args ){
		$form_id = $args['form_id'];
		$mode = $args['mode'];
		$fields = unserialize( $args['custom_fields'] );
		if ( $mode == 'register' ){
			do_action("um_ajax_submit_form_errors_hook__registration", $args );
		}
		do_action("um_ajax_submit_form_errors_hook__blockedips", $args );
		do_action("um_ajax_submit_form_errors_hook__blockedemails", $args );
		if ( $mode == 'login' ) {
            //stays the same
			do_action('um_submit_form_errors_hook_login', $args );
			do_action('um_ajax_submit_form_errors_hook_logincheck', $args );
		} else {
            //stays the same
			do_action('um_submit_form_errors_hook_', $args );
			do_action("um_ajax_submit_form_errors_hook__blockedwords", $args );
		}
	}
	/***
	***	@Error processing hook : standard
	***/

    //stays the same
	//add_action('um_submit_form_errors_hook_', 'um_submit_form_errors_hook_', 10);
