<?php
/*
Plugin Name: Ajax Forms for Ultimate Member
Plugin URI: http://ajaxy.org
Description: Tranform your static ultimate member forms to ajax
Version: 2.0.2
Author: Naji Amer - @n-for-all
Author URI: http://ajaxy.org
*/


if (is_admin()) {
    require_once 'admin/license.php';
    require_once 'admin/settings.php';
}


/* Not tested with older versions of Ultimate Member, lower the version number at your own risk */
define("AJAXY_UM_FORMS_REQUIRED_VERSION", "2.0");


define("AJAXY_UM_FORMS_TEXT_DOMAIN", "um-ajax");
define("AJAXY_UM_FORMS_PLUGIN_URL", plugins_url('', __FILE__));

class Ajaxy_UM_Forms_Screen
{
    public function in_admin()
    {
        return false;
    }
}
class Ajaxy_UM_Forms
{
    private $license = null;
    private $vars = array();
    public $notice = false;
    public function __construct()
    {
        add_action('plugins_loaded', array(&$this, 'plugins_loaded'), 100);
    }
    public function plugins_loaded()
    {
        if (defined('ultimatemember_version') && version_compare(ultimatemember_version, AJAXY_UM_FORMS_REQUIRED_VERSION) >= 0) {
            include_once('includes/um-ajax-actions-form.php');
            include_once('includes/um-ajax-actions-login.php');
            include_once('includes/um-ajax-actions-register.php');
            include_once('includes/um-ajax-actions-misc.php');
            $this->filters();
            $this->actions();
        } else {
            add_action('admin_notices', array(&$this, 'version_notice__error'));
        }
    }

    public function filters()
    {
        add_filter('um_settings_structure', array(&$this, 'um_settings_structure'), 10, 1);
        add_filter('um_change_settings_before_save', array(&$this, 'um_change_settings_before_save'), 10, 1);
    }
    public function um_change_settings_before_save($post){
        if($post && isset($post['ajaxy_um_license'])){
            global $Ajaxy_UM_Forms_License;
            $setting = isset($post['ajaxy_um_license']) ? $post['ajaxy_um_license']: false;
            if($setting !== false){
                $active = $Ajaxy_UM_Forms_License->active($setting);
                if($active === true){
                    update_option('ajaxy_um_license_status', ['type' => 'success', 'message' => 'Ajaxy UM license is activated']);
                    $this->notice = ['type' => 'success', 'message' => 'Your license is activated'];
                }else{
                    update_option('ajaxy_um_license_status', ['type' => 'error', 'message' => 'Ajaxy UM license failed to activate, Error: '.$active]);
                    $this->notice = ['type' => 'error', 'message' => $active];
                }
            }
        }

        return $post;
    }
    public function license_notice() {
        $this->notice = get_option('ajaxy_um_license_status');
        if($this->notice){
            ?>
            <div class="notice notice-<?php echo $this->notice['type']; ?> is-dismissible">
                <p><?php _e( $this->notice['message'] ); ?></p>
            </div>
            <?php
            delete_option('ajaxy_um_license_status');
        }
    }
    public function um_settings_structure($settings){
        $settings['ajaxy_um'] = array (
            'title' => 'Ajaxy License',
            'fields' =>
            array (
              array (
                'id' => 'ajaxy_um_license',
                'type' => 'text',
                'label' => 'License key',
                'tooltip' => 'The license key you have received via email to unlock the full functionality of the plugin',
                'size' => 'medium',
              )
          ),
        );
        return $settings;
    }
    public function head()
    {
        $forms = get_option("_ajaxy_umajax_forms");
        if (!$forms) {
            $forms = array();
        }
        $classes = array();
        foreach ($forms as $form) {
            $classes[] = ".um-".trim($form);
        }
        echo '<script type="text/javascript">
         var um_ajax = { endpoint: "'.admin_url('admin-ajax.php').'", forms: "'.implode(",", $classes).'"};
        </script>
        ';
    }
    public function actions()
    {
        add_action( 'admin_notices', array(&$this, 'license_notice' ));
        add_action('wp_ajax_um_submit_form', array(&$this,'um_submit_form'));
        add_action('wp_ajax_nopriv_um_submit_form', array(&$this,'um_submit_form'));
        add_action('wp_head', array(&$this,'head'));

        add_action('admin_enqueue_scripts', array(&$this, 'admin_scripts'));

        add_action('wp_enqueue_scripts', array(&$this, 'scripts'));
        add_action('um_after_form', array(&$this, 'um_after_form'));


        if (isset($_POST['ajaxy-umajax-mode']) && defined('DOING_AJAX') && DOING_AJAX) {
            $this->setup_screen();
            add_action('init', array(&$this, 'form_init'), 1);
        }
    }
    public function form_init()
    {
        global $wp_filter;
        //login
        remove_action('um_submit_form_login', 'um_submit_form_login', 10);
        add_action('um_submit_form_login', 'um_ajax_submit_form_login', 10);

        //register
        remove_action('um_submit_form_register', 'um_submit_form_register', 10);
        add_action('um_submit_form_register', 'um_ajax_submit_form_register', 10);

        remove_action('um_submit_form_errors_hook', 'um_submit_form_errors_hook', 10);
        add_action('um_submit_form_errors_hook', 'um_ajax_submit_form_errors_hook', 10);

        foreach ($wp_filter['template_redirect']->callbacks as $hook) {
            foreach ($hook as $function) {
                if (is_array($function['function']) && sizeof($function['function']) == 2) {
                    if ($function['function'][0] instanceof \um\core\Form) {
                        add_action('um_ajax_submit', $function['function']);
                    }
                }
            }
        }
    }
    public function um_submit_form()
    {
        $json = array('status' => 'submit', 'message' => '', 'redirect' => false);
        if(has_action('um_ajax_submit')){
            do_action('um_ajax_submit');
        }else{
            $debug = WP_DEBUG === true ? 'Invalid setup have been detected, The plugin couldn\'t find "ajaxy-umajax-mode" hidden input to fire the action "um_ajax_submit" on the form.': 'An error has occured and your form couldn\'t be submitted';
            wp_die(wp_json_encode(
                array_replace($json, array(
                    'status' => 'submit',
                    'message' => $debug,
                    'redirect' => false
                ))
            ));
        }
    }
    public function version_notice__error()
    {
        $class = 'notice notice-error';
        $message = __('Ajax forms for Ultimate Member requires Ultimate Member version '.AJAXY_UM_FORMS_REQUIRED_VERSION.' or higher.', AJAXY_UM_FORMS_TEXT_DOMAIN);

        printf('<div class="%1$s"><p>%2$s</p></div>', $class, $message);
    }
    public function admin_scripts()
    {
        wp_enqueue_style(AJAXY_UM_FORMS_TEXT_DOMAIN."-style", AJAXY_UM_FORMS_PLUGIN_URL. '/admin/css/styles.css');
    }
    public function scripts()
    {
        $in_footer = true;
        wp_enqueue_script(AJAXY_UM_FORMS_TEXT_DOMAIN, AJAXY_UM_FORMS_PLUGIN_URL. '/js/front.js', array( 'jquery' ), "1.0.0", $in_footer);
        wp_enqueue_style(AJAXY_UM_FORMS_TEXT_DOMAIN."-style", AJAXY_UM_FORMS_PLUGIN_URL. '/css/styles.css');
    }
    public function setup_screen()
    {
        if (!isset($GLOBALS['current_screen'])) {
            $GLOBALS['current_screen'] = new Ajaxy_UM_Forms_Screen();
        }
    }
    public function um_after_form($args)
    {
        if ($args['mode']) { ?>
        <input type="hidden" name="ajaxy-umajax-mode" value="<?php echo $args['mode']; ?>" />
        <?php
        }
    }
}
global $Ajaxy_UM_Forms;
if(!$Ajaxy_UM_Forms){
    $Ajaxy_UM_Forms = new Ajaxy_UM_Forms();
}
